@@ -1,6 +1,6 @@
 "ordispider" <-
     function (ord, groups, display = "sites", w = weights(ord, display),
-              show.groups, ...)
+              show.groups, label = FALSE, ...)
 {
     weights.default <- function(object, ...) NULL
     if (inherits(ord, "cca") && missing(groups)) {
@@ -11,6 +11,9 @@
         return(invisible())
     }
     pts <- scores(ord, display = display, ...)
+    ## ordihull: draw lines from centre to the points in the hull
+    if (inherits(ord, "ordihull"))
+        groups <- attr(pts, "hulls")
     w <- eval(w)
     if (length(w) == 1)
         w <- rep(1, nrow(pts))
@@ -24,6 +27,8 @@
     }
     out <- seq(along = groups)
     inds <- names(table(groups))
+    if (label) 
+    cntrs <- names <- NULL
     for (is in inds) {
         gr <- out[groups == is]
         if (length(gr) > 1) {
@@ -32,7 +37,13 @@
             ave <- apply(X, 2, weighted.mean, w = W)
             ordiArgAbsorber(ave[1], ave[2], X[, 1], X[, 2],
                             FUN = segments, ...)
+            if (label) {
+                cntrs <- rbind(cntrs, ave)
+                names <- c(names, is)
+            }
         }
     }
+    if (label) 
+        ordiArgAbsorber(cntrs, label = names, FUN = ordilabel, ...)
     invisible()
 }
