@@ -25,6 +25,10 @@
     if (type %in% c("response", "working")) {
         if (!is.null(object$pCCA)) 
             warning("Conditional ('partial') component ignored")
+        if (!missing(newdata)) {
+            u <- predict(object, type = if(model == "CCA") "lc" else "wa",
+                         newdata = newdata, rank = take)
+        }
         if (inherits(object, "capscale")) {
             if (take > 0)
                 out <- dist(u %*% slam/sqrt(nr))
